Базовый класс реализующий основной функционал устройства по спецификации OCF.

Под устройством согласно спецификации OCF понимается логический объект принимающий одну или несколько ролей.

Основное применение это реализация мостов к не OCF устройствам (OCF Bridge)  и реализация приложений взаимодействующих с устройствами,
такие как Профилер, Планировщик.

Соглашение по заполнению параметров для мостов:

Ресурс /oic/d
* dmn - разработчик класса реализующего мост, 
* dmno - имя класса реализующего мост, заполняется автоматически при инициализации класса
* sv  - версия класса реализующего мост, заполняется автоматически из \_\_init\_\_.py модуля

Ресурс /oic/p
* mnpv - bubot \[версия bubot\] заполняется автоматически
* остальные поля заполняются параметрами физического устройства к которому делаем мост
